==> fispro_3.4.orig.tar.gz: fispro-3.4/java/makefile.util.java <==
##########################################################################
##            MAKEFILE FOR UTIL                                         ##
##                                                                      ##
##     Usage :                                                          ##
##                                                                      ##
##          Compilation : make all                                      ##
##                                                                      ##
##          Nettoyage : make clean                                      ##
##                                                                      ##
##########################################################################

#################################
# Configuration du makefile     #
# Configuration of the Makefile #
#################################
# the following lines are machine dependent
# path separator: / on linux/unix, \\ on Windows
#SEP		:= \\
SEP		:= /
# classpath separator: : on linux/unix, ; on Windows
#CLASSPATH_SEP   := ;
CLASSPATH_SEP   := :
# rm on linux/unix, del on Windows
#CMD_RM          := del
CMD_RM          := rm
# java path
#JAVA_PATH       := C:\\jbuilder8\\jdk1.4\\bin\\
JAVA_PATH       := /usr/local/jdk1.4/bin/
# end machine dependent lines

PROJECT_PATH       := ./
BIN_CLASS_PATH     := ..$(SEP)bin$(SEP)class
BIN_JAR_PATH       := ..$(SEP)bin$(SEP)jar
CLASS_PATH         := $(BIN_CLASS_PATH)
PACKAGES           := util/histogram util/polygon2d util/tableheader util/treetable util/sortabletable util/regression util/mthumbslider util/skt/swing/border util
EMPTY              :=
CMD_JAVAC          := $(JAVA_PATH)javac -g -deprecation
CMD_JAR            := $(JAVA_PATH)jar

#############################################################
# Ceci est un truc                                          #
# This is a trick				            #
#############################################################
# those words must be unused words such as kgfh.
CLEAN_CODE := clean_
CMP_CODE   := cmp_

HPACKAGES := $(patsubst %,$(CMP_CODE)%,$(PACKAGES))
CPACKAGES := $(patsubst %,$(CLEAN_CODE)%,$(PACKAGES))

##############
# Les rgles #
# The rules  #
##############
all: build jar

#############################
# Compile tous les fichiers #
# Compile all the files     #
#############################
build : $(HPACKAGES)
	@echo $(PACKAGES)
	@echo '===' Compilation Completed

######################################
# Compile les fichiers d'un package  #
# Compile all files in a package     #
######################################
$(HPACKAGES) :
	@echo Compilation de $(subst $(CMP_CODE),$(EMPTY), $@)
	$(CMD_JAVAC) -d $(BIN_CLASS_PATH) -classpath $(CLASS_PATH) $(PROJECT_PATH)$(subst $(CMP_CODE),$(EMPTY),$@)/*.java

################################################################
# Cree le fichier jar contenant les classes java	       #
# Create the jar file holding the java classes                 #
################################################################
jar:
	@echo creating util.jar
	$(CMD_JAR) cf $(BIN_JAR_PATH)/util.jar -C $(BIN_CLASS_PATH) util
	@echo util.jar completed

################################################################
# Supprime les fichiers non necessaires d'un package  	       #
# Delete the file not needed from a package                    #
################################################################
clean : $(CPACKAGES)
	@echo $(PACKAGES)
	@echo deletion '==='  Completed

$(CPACKAGES) :
	$(CMD_RM) $(BIN_CLASS_PATH)$(SEP)$(subst $(CLEAN_CODE),$(EMPTY),$@)$(SEP)*.class

==> fispro_3.5.orig.tar.gz: fispro-3.5/java/makefile.util.java <==
##########################################################################
##            MAKEFILE FOR UTIL                                         ##
##                                                                      ##
##     Usage :                                                          ##
##                                                                      ##
##          Compilation : make all                                      ##
##                                                                      ##
##          Nettoyage : make clean                                      ##
##                                                                      ##
##########################################################################

#################################
# Configuration du makefile     #
# Configuration of the Makefile #
#################################
# the following lines are machine dependent
# path separator: / on linux/unix, \\ on Windows
#SEP		:= \\
SEP		:= /
# classpath separator: : on linux/unix, ; on Windows
#CLASSPATH_SEP   := ;
CLASSPATH_SEP   := :
# rm on linux/unix, del on Windows
#CMD_RM          := del
CMD_RM          := rm
# java path
#JAVA_PATH       := C:\\jbuilder8\\jdk1.4\\bin\\
JAVA_PATH       := /E/Dev/java/jdk/1.6.0_22/bin/
# end machine dependent lines

PROJECT_PATH       := ./
BIN_CLASS_PATH     := ..$(SEP)bin$(SEP)class
BIN_JAR_PATH       := ..$(SEP)bin$(SEP)jar
JGOODIES_CLASS_PATH := $(BIN_JAR_PATH)$(SEP)jgoodies-binding-2.6.1.jar$(CLASSPATH_SEP)$(BIN_JAR_PATH)$(SEP)jgoodies-common-1.3.1.jar$(CLASSPATH_SEP)$(BIN_JAR_PATH)$(SEP)jgoodies-validation-2.4.1.jar
GUAVA_CLASS_PATH   := $(BIN_JAR_PATH)$(SEP)guava-12.0.jar
CLONING_CLASS_PATH := $(BIN_JAR_PATH)$(SEP)cloning-1.8.5.jar$(CLASSPATH_SEP)$(BIN_JAR_PATH)$(SEP)objenesis-1.2.jar
JGA_CLASS_PATH     := $(BIN_JAR_PATH)$(SEP)jga-0.8.1.jar
APACHE_CLASS_PATH  := $(BIN_JAR_PATH)$(SEP)commons-lang-2.6.jar$(CLASSPATH_SEP)$(BIN_JAR_PATH)$(SEP)commons-io-2.0.1.jar
JFREE_CLASS_PATH   := $(BIN_JAR_PATH)$(SEP)jfreechart-1.0.14.jar
CLASS_PATH         := $(BIN_CLASS_PATH)$(CLASSPATH_SEP)$(JGOODIES_CLASS_PATH)$(CLASSPATH_SEP)$(GUAVA_CLASS_PATH)$(CLASSPATH_SEP)$(CLONING_CLASS_PATH)$(CLASSPATH_SEP)$(JGA_CLASS_PATH)$(CLASSPATH_SEP)$(APACHE_CLASS_PATH)$(CLASSPATH_SEP)$(JFREE_CLASS_PATH)
PACKAGES           := util/histogram util/polygon2d util/tableheader util/treetable util/sortabletable util/regression util/mthumbslider util/skt/swing/border util util/swing/dialog util/bean com/humaorie/dollar util/swing/text util/swing util/swing/dialog/validation util/jgoodies/binding/beans util/jgoodies/binding/list util/jgoodies/binding/value util/jgoodies/common/bean util/jgoodies/validation util/jgoodies/validation/range util/jgoodies/binding util/algorithm/distance/minkowski util/jfree/data/xy util/swing/action/performable util/swing/action/throwable util/swing/algorithm/distance/minkowski util/swing/io
EMPTY              :=
CMD_JAVAC          := $(JAVA_PATH)javac -g -deprecation
CMD_JAR            := $(JAVA_PATH)jar

#############################################################
# Ceci est un truc                                          #
# This is a trick				            #
#############################################################
# those words must be unused words such as kgfh.
CLEAN_CODE := clean_
CMP_CODE   := cmp_

HPACKAGES := $(patsubst %,$(CMP_CODE)%,$(PACKAGES))
CPACKAGES := $(patsubst %,$(CLEAN_CODE)%,$(PACKAGES))

##############
# Les rgles #
# The rules  #
##############
all: build jar

#############################
# Compile tous les fichiers #
# Compile all the files     #
#############################
build : $(HPACKAGES)
	@echo $(PACKAGES)
	@echo '===' Compilation Completed

######################################
# Compile les fichiers d'un package  #
# Compile all files in a package     #
######################################
$(HPACKAGES) :
	@echo Compilation de $(subst $(CMP_CODE),$(EMPTY), $@)
	$(CMD_JAVAC) -d $(BIN_CLASS_PATH) -classpath $(CLASS_PATH) $(PROJECT_PATH)$(subst $(CMP_CODE),$(EMPTY),$@)/*.java

################################################################
# Cree le fichier jar contenant les classes java	       #
# Create the jar file holding the java classes                 #
################################################################
jar:
	@echo creating util.jar
	$(CMD_JAR) cf $(BIN_JAR_PATH)/util.jar -C $(BIN_CLASS_PATH) util -C $(BIN_CLASS_PATH) com
	@echo util.jar completed

################################################################
# Supprime les fichiers non necessaires d'un package  	       #
# Delete the file not needed from a package                    #
################################################################
clean : $(CPACKAGES)
	@echo $(PACKAGES)
	@echo deletion '==='  Completed

$(CPACKAGES) :
	$(CMD_RM) $(BIN_CLASS_PATH)$(SEP)$(subst $(CLEAN_CODE),$(EMPTY),$@)$(SEP)*.class
